# AI Auxiliar

Esse pacote é uma invenção da minha mente "brilhante", que tem apenas a finalidade de me ensinar a publicar um pacote no Pypi.

* Passos para a instalação - Não tem.
* Outras informações relevantes - Também não tem não.
* Autor - Sou eu mesmo, Guilherme Menezes.